Class: Sendpost::BlacklistResource
- Inherits:
-
Object
- Object
- Sendpost::BlacklistResource
- Defined in:
- lib/sendpost_ruby_sdk/models/blacklist_resource.rb
Overview
Blacklist status entry for a monitored domain or IP address, including the list of RBLs it is currently listed on and associated report links.
Instance Attribute Summary collapse
-
#add_date ⇒ Object
UNIX epoch timestamp when the resource was added to monitoring.
-
#blacklisted_count ⇒ Object
Number of RBLs the target is currently listed on (string-encoded).
-
#blacklisted_on ⇒ Object
The specific RBLs this target is currently listed on.
-
#contact_list_id ⇒ Object
Identifier of the contact list associated with this resource, if any.
-
#id ⇒ Object
Unique identifier of the blacklist resource entry.
-
#label ⇒ Object
User-assigned label for the monitored resource.
-
#last_check ⇒ Object
UNIX epoch timestamp of the most recent blacklist check.
-
#links ⇒ Object
Returns the value of attribute links.
-
#status ⇒ Object
Current blacklist status of the target (e.g.
clean,listed). -
#target ⇒ Object
The domain or IP address being monitored for blacklisting.
-
#type ⇒ Object
The kind of target being monitored (e.g.
domainorip).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BlacklistResource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BlacklistResource
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendpost::BlacklistResource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendpost::BlacklistResource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'add_date') self.add_date = attributes[:'add_date'] end if attributes.key?(:'last_check') self.last_check = attributes[:'last_check'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'label') self.label = attributes[:'label'] end if attributes.key?(:'contact_list_id') self.contact_list_id = attributes[:'contact_list_id'] end if attributes.key?(:'blacklisted_count') self.blacklisted_count = attributes[:'blacklisted_count'] end if attributes.key?(:'blacklisted_on') if (value = attributes[:'blacklisted_on']).is_a?(Array) self.blacklisted_on = value end end if attributes.key?(:'links') self.links = attributes[:'links'] end end |
Instance Attribute Details
#add_date ⇒ Object
UNIX epoch timestamp when the resource was added to monitoring.
29 30 31 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 29 def add_date @add_date end |
#blacklisted_count ⇒ Object
Number of RBLs the target is currently listed on (string-encoded).
44 45 46 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 44 def blacklisted_count @blacklisted_count end |
#blacklisted_on ⇒ Object
The specific RBLs this target is currently listed on.
47 48 49 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 47 def blacklisted_on @blacklisted_on end |
#contact_list_id ⇒ Object
Identifier of the contact list associated with this resource, if any.
41 42 43 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 41 def contact_list_id @contact_list_id end |
#id ⇒ Object
Unique identifier of the blacklist resource entry.
20 21 22 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 20 def id @id end |
#label ⇒ Object
User-assigned label for the monitored resource.
38 39 40 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 38 def label @label end |
#last_check ⇒ Object
UNIX epoch timestamp of the most recent blacklist check.
32 33 34 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 32 def last_check @last_check end |
#links ⇒ Object
Returns the value of attribute links.
49 50 51 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 49 def links @links end |
#status ⇒ Object
Current blacklist status of the target (e.g. clean, listed).
35 36 37 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 35 def status @status end |
#target ⇒ Object
The domain or IP address being monitored for blacklisting.
26 27 28 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 26 def target @target end |
#type ⇒ Object
The kind of target being monitored (e.g. domain or ip).
23 24 25 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 23 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 236 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Sendpost.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 52 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'target' => :'target', :'add_date' => :'addDate', :'last_check' => :'lastCheck', :'status' => :'status', :'label' => :'label', :'contact_list_id' => :'contactListId', :'blacklisted_count' => :'blacklistedCount', :'blacklisted_on' => :'blacklistedOn', :'links' => :'links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 212 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 79 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'target' => :'String', :'add_date' => :'Integer', :'last_check' => :'Integer', :'status' => :'String', :'label' => :'String', :'contact_list_id' => :'String', :'blacklisted_count' => :'String', :'blacklisted_on' => :'Array<BlacklistedOn>', :'links' => :'BlacklistLinks' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && target == o.target && add_date == o.add_date && last_check == o.last_check && status == o.status && label == o.label && contact_list_id == o.contact_list_id && blacklisted_count == o.blacklisted_count && blacklisted_on == o.blacklisted_on && links == o.links end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 307 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 205 def hash [id, type, target, add_date, last_check, status, label, contact_list_id, blacklisted_count, blacklisted_on, links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
283 284 285 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 283 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
277 278 279 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 277 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 |
# File 'lib/sendpost_ruby_sdk/models/blacklist_resource.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |