Class: Sendpost::EmailAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/sendpost_ruby_sdk/models/email_address.rb

Overview

An email address with an optional display name

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailAddress

Initializes the object



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendpost::EmailAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendpost::EmailAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#email ⇒ Object

The email address (must be a valid email format)



20
21
22
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 20

def email
  @email
end

#name ⇒ Object

Display name shown in email clients. Will appear as "Name [email protected]" in the From/To fields.



23
24
25
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 23

def name
  @name
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 181

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Sendpost.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



34
35
36
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 26

def self.attribute_map
  {
    :'email' => :'email',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



52
53
54
55
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 44

def self.openapi_types
  {
    :'email' => :'String',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



135
136
137
138
139
140
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 135

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      name == o.name
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 252

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


144
145
146
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 144

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



150
151
152
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 150

def hash
  [email, name].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 86

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)



228
229
230
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 228

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object



222
223
224
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 222

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



102
103
104
105
106
107
# File 'lib/sendpost_ruby_sdk/models/email_address.rb', line 102

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  return false if !@name.nil? && @name.to_s.length > 256
  true
end