Class: Sendpost::EmailMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/sendpost_ruby_sdk/models/email_message.rb

Overview

Complete email message details included in webhook payloads. This contains all the original email data plus routing information.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ EmailMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Sendpost::EmailMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Sendpost::EmailMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message_id')
    self.message_id = attributes[:'message_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'sub_account_id')
    self. = attributes[:'sub_account_id']
  end

  if attributes.key?(:'ip_id')
    self.ip_id = attributes[:'ip_id']
  end

  if attributes.key?(:'public_ip')
    self.public_ip = attributes[:'public_ip']
  end

  if attributes.key?(:'local_ip')
    self.local_ip = attributes[:'local_ip']
  end

  if attributes.key?(:'email_type')
    self.email_type = attributes[:'email_type']
  end

  if attributes.key?(:'submitted_at')
    self. = attributes[:'submitted_at']
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'reply_to')
    self.reply_to = attributes[:'reply_to']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'ip_pool')
    self.ip_pool = attributes[:'ip_pool']
  end

  if attributes.key?(:'headers')
    if (value = attributes[:'headers']).is_a?(Hash)
      self.headers = value
    end
  end

  if attributes.key?(:'custom_fields')
    if (value = attributes[:'custom_fields']).is_a?(Hash)
      self.custom_fields = value
    end
  end

  if attributes.key?(:'track_opens')
    self.track_opens = attributes[:'track_opens']
  end

  if attributes.key?(:'track_clicks')
    self.track_clicks = attributes[:'track_clicks']
  end

  if attributes.key?(:'webhook_endpoint')
    self.webhook_endpoint = attributes[:'webhook_endpoint']
  end
end

Instance Attribute Details

#account_id ⇒ Object

ID of the SendPost account that sent this email



23
24
25
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 23

def 
  @account_id
end

#custom_fields ⇒ Object

Custom fields sent with the email, available for personalization



62
63
64
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 62

def custom_fields
  @custom_fields
end

#email_type ⇒ Object

Classification of the email based on recipient domain: - gmail - Gmail recipient - yahoo - Yahoo recipient - microsoft - Outlook/Hotmail recipient - default - Other email providers



38
39
40
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 38

def email_type
  @email_type
end

#from ⇒ Object

The sender's email address



44
45
46
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 44

def from
  @from
end

#groups ⇒ Object

Tags/groups for categorization and analytics



53
54
55
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 53

def groups
  @groups
end

#headers ⇒ Object

Custom headers included in the email



59
60
61
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 59

def headers
  @headers
end

#ip_id ⇒ Object

ID of the dedicated IP used for sending (0 if a shared IP was used)



29
30
31
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 29

def ip_id
  @ip_id
end

#ip_pool ⇒ Object

Name of the IP pool used for sending



56
57
58
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 56

def ip_pool
  @ip_pool
end

#local_ip ⇒ Object

The internal/local IP address used to send this email



35
36
37
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 35

def local_ip
  @local_ip
end

#message_id ⇒ Object

Unique identifier for this email message



20
21
22
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 20

def message_id
  @message_id
end

#public_ip ⇒ Object

The public IP address used to send this email



32
33
34
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 32

def public_ip
  @public_ip
end

#reply_to ⇒ Object

The reply-to address (if different from sender)



47
48
49
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 47

def reply_to
  @reply_to
end

#sub_account_id ⇒ Object

ID of the sub-account that sent this email



26
27
28
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 26

def 
  
end

#submitted_at ⇒ Object

UNIX epoch timestamp in nanoseconds when the email was submitted



41
42
43
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 41

def 
  @submitted_at
end

#to ⇒ Object

The envelope recipient (actual delivery address)



50
51
52
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 50

def to
  @to
end

#track_clicks ⇒ Object

Whether click tracking was enabled



68
69
70
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 68

def track_clicks
  @track_clicks
end

#track_opens ⇒ Object

Whether open tracking was enabled



65
66
67
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 65

def track_opens
  @track_opens
end

#webhook_endpoint ⇒ Object

Custom webhook endpoint for this email (if specified)



71
72
73
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 71

def webhook_endpoint
  @webhook_endpoint
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string —

    type Data type

  • string —

    value Value to be deserialized

Returns:

  • (Object) —

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 311

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Sendpost.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



98
99
100
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 74

def self.attribute_map
  {
    :'message_id' => :'messageID',
    :'account_id' => :'accountID',
    :'sub_account_id' => :'subAccountID',
    :'ip_id' => :'ipID',
    :'public_ip' => :'publicIP',
    :'local_ip' => :'localIP',
    :'email_type' => :'emailType',
    :'submitted_at' => :'submittedAt',
    :'from' => :'from',
    :'reply_to' => :'replyTo',
    :'to' => :'to',
    :'groups' => :'groups',
    :'ip_pool' => :'ipPool',
    :'headers' => :'headers',
    :'custom_fields' => :'customFields',
    :'track_opens' => :'trackOpens',
    :'track_clicks' => :'trackClicks',
    :'webhook_endpoint' => :'webhookEndpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 287

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



132
133
134
135
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 108

def self.openapi_types
  {
    :'message_id' => :'String',
    :'account_id' => :'Integer',
    :'sub_account_id' => :'Integer',
    :'ip_id' => :'Integer',
    :'public_ip' => :'String',
    :'local_ip' => :'String',
    :'email_type' => :'String',
    :'submitted_at' => :'Integer',
    :'from' => :'EmailAddress',
    :'reply_to' => :'EmailAddress',
    :'to' => :'Recipient',
    :'groups' => :'Array<String>',
    :'ip_pool' => :'String',
    :'headers' => :'Hash<String, String>',
    :'custom_fields' => :'Hash<String, Object>',
    :'track_opens' => :'Boolean',
    :'track_clicks' => :'Boolean',
    :'webhook_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message_id == o.message_id &&
       == o. &&
       == o. &&
      ip_id == o.ip_id &&
      public_ip == o.public_ip &&
      local_ip == o.local_ip &&
      email_type == o.email_type &&
       == o. &&
      from == o.from &&
      reply_to == o.reply_to &&
      to == o.to &&
      groups == o.groups &&
      ip_pool == o.ip_pool &&
      headers == o.headers &&
      custom_fields == o.custom_fields &&
      track_opens == o.track_opens &&
      track_clicks == o.track_clicks &&
      webhook_endpoint == o.webhook_endpoint
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object) —

    Any valid value

Returns:

  • (Hash) —

    Returns the value in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 382

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 274

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



280
281
282
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 280

def hash
  [message_id, , , ip_id, public_ip, local_ip, email_type, , from, reply_to, to, groups, ip_pool, headers, custom_fields, track_opens, track_clicks, webhook_endpoint].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_body ⇒ Hash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash) —

    Returns the object in the form of hash



358
359
360
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 358

def to_body
  to_hash
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_s ⇒ String

Returns the string representation of the object

Returns:

  • (String) —

    String presentation of the object



352
353
354
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 352

def to_s
  to_hash.to_s
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



242
243
244
245
# File 'lib/sendpost_ruby_sdk/models/email_message.rb', line 242

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end