Class: Sendpost::Domain
- Inherits:
-
Object
- Object
- Sendpost::Domain
- Defined in:
- lib/sendpost_ruby_sdk/models/domain.rb
Overview
A sending domain configured for email delivery. Domains must be verified via DNS records before they can be used for sending. SendPost requires DKIM authentication and recommends configuring Return-Path, DMARC, and tracking records for optimal deliverability.
Instance Attribute Summary collapse
-
#created ⇒ Object
UNIX epoch timestamp in nanoseconds when the domain was added to SendPost.
-
#dkim ⇒ Object
DKIM (DomainKeys Identified Mail) DNS record configuration.
-
#dkim_failure_reason ⇒ Object
Detailed reason if DKIM verification failed (empty if verified or not attempted).
-
#dkim_verified ⇒ Object
Whether the DKIM DNS record has been verified successfully.
-
#dmarc ⇒ Object
DMARC (Domain-based Message Authentication, Reporting & Conformance) DNS record.
-
#dmarc_failure_reason ⇒ Object
Detailed reason if DMARC verification failed.
-
#dmarc_verified ⇒ Object
Whether the DMARC DNS record has been verified successfully.
-
#dns_provider ⇒ Object
Auto-detected DNS provider for this domain (e.g. "cloudflare", "other"), used to tailor DNS-setup instructions.
-
#domain_registered_date ⇒ Object
Date when this domain was originally registered (from WHOIS).
-
#id ⇒ Object
Unique identifier for the domain.
-
#name ⇒ Object
The domain name (e.g., "example.com").
-
#return_path ⇒ Object
Return-Path (bounce handling) DNS record configuration.
-
#return_path_failure_reason ⇒ Object
Detailed reason if Return-Path verification failed.
-
#return_path_verified ⇒ Object
Whether the Return-Path DNS record has been verified successfully.
-
#track ⇒ Object
Tracking domain DNS record configuration.
-
#track_failure_reason ⇒ Object
Detailed reason if tracking domain verification failed.
-
#track_verified ⇒ Object
Whether the tracking domain DNS record has been verified successfully.
-
#verified ⇒ Object
Overall verification status.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Domain
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Domain
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Sendpost::Domain` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Sendpost::Domain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'dns_provider') self.dns_provider = attributes[:'dns_provider'] end if attributes.key?(:'dkim') self.dkim = attributes[:'dkim'] end if attributes.key?(:'return_path') self.return_path = attributes[:'return_path'] end if attributes.key?(:'track') self.track = attributes[:'track'] end if attributes.key?(:'dmarc') self.dmarc = attributes[:'dmarc'] end if attributes.key?(:'dkim_verified') self.dkim_verified = attributes[:'dkim_verified'] end if attributes.key?(:'dmarc_verified') self.dmarc_verified = attributes[:'dmarc_verified'] end if attributes.key?(:'return_path_verified') self.return_path_verified = attributes[:'return_path_verified'] end if attributes.key?(:'track_verified') self.track_verified = attributes[:'track_verified'] end if attributes.key?(:'verified') self.verified = attributes[:'verified'] end if attributes.key?(:'domain_registered_date') self.domain_registered_date = attributes[:'domain_registered_date'] end if attributes.key?(:'created') self.created = attributes[:'created'] end if attributes.key?(:'dkim_failure_reason') self.dkim_failure_reason = attributes[:'dkim_failure_reason'] end if attributes.key?(:'dmarc_failure_reason') self.dmarc_failure_reason = attributes[:'dmarc_failure_reason'] end if attributes.key?(:'track_failure_reason') self.track_failure_reason = attributes[:'track_failure_reason'] end if attributes.key?(:'return_path_failure_reason') self.return_path_failure_reason = attributes[:'return_path_failure_reason'] end end |
Instance Attribute Details
#created ⇒ Object
UNIX epoch timestamp in nanoseconds when the domain was added to SendPost
59 60 61 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 59 def created @created end |
#dkim ⇒ Object
DKIM (DomainKeys Identified Mail) DNS record configuration. DKIM cryptographically signs your emails to verify they haven't been tampered with. This is REQUIRED for sending emails.
29 30 31 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 29 def dkim @dkim end |
#dkim_failure_reason ⇒ Object
Detailed reason if DKIM verification failed (empty if verified or not attempted)
62 63 64 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 62 def dkim_failure_reason @dkim_failure_reason end |
#dkim_verified ⇒ Object
Whether the DKIM DNS record has been verified successfully
41 42 43 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 41 def dkim_verified @dkim_verified end |
#dmarc ⇒ Object
DMARC (Domain-based Message Authentication, Reporting & Conformance) DNS record. DMARC builds on DKIM and SPF to provide email authentication and reporting. RECOMMENDED for enterprise senders.
38 39 40 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 38 def dmarc @dmarc end |
#dmarc_failure_reason ⇒ Object
Detailed reason if DMARC verification failed
65 66 67 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 65 def dmarc_failure_reason @dmarc_failure_reason end |
#dmarc_verified ⇒ Object
Whether the DMARC DNS record has been verified successfully
44 45 46 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 44 def dmarc_verified @dmarc_verified end |
#dns_provider ⇒ Object
Auto-detected DNS provider for this domain (e.g. "cloudflare", "other"), used to tailor DNS-setup instructions. Read-only.
26 27 28 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 26 def dns_provider @dns_provider end |
#domain_registered_date ⇒ Object
Date when this domain was originally registered (from WHOIS). Newer domains may have lower sender reputation initially.
56 57 58 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 56 def domain_registered_date @domain_registered_date end |
#id ⇒ Object
Unique identifier for the domain
20 21 22 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 20 def id @id end |
#name ⇒ Object
The domain name (e.g., "example.com"). This is the domain portion of your sending email addresses.
23 24 25 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 23 def name @name end |
#return_path ⇒ Object
Return-Path (bounce handling) DNS record configuration. Configuring this allows bounce notifications to be properly routed through SendPost. RECOMMENDED for better deliverability.
32 33 34 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 32 def return_path @return_path end |
#return_path_failure_reason ⇒ Object
Detailed reason if Return-Path verification failed
71 72 73 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 71 def return_path_failure_reason @return_path_failure_reason end |
#return_path_verified ⇒ Object
Whether the Return-Path DNS record has been verified successfully
47 48 49 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 47 def return_path_verified @return_path_verified end |
#track ⇒ Object
Tracking domain DNS record configuration. When configured, click tracking links use your domain instead of SendPost's domain. RECOMMENDED for brand consistency and improved click-through rates.
35 36 37 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 35 def track @track end |
#track_failure_reason ⇒ Object
Detailed reason if tracking domain verification failed
68 69 70 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 68 def track_failure_reason @track_failure_reason end |
#track_verified ⇒ Object
Whether the tracking domain DNS record has been verified successfully
50 51 52 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 50 def track_verified @track_verified end |
#verified ⇒ Object
Overall verification status. True only if DKIM is verified (minimum requirement). For full verification, configure all DNS records.
53 54 55 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 53 def verified @verified end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 305 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Sendpost.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
98 99 100 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 98 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 103 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 74 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'dns_provider' => :'dnsProvider', :'dkim' => :'dkim', :'return_path' => :'returnPath', :'track' => :'track', :'dmarc' => :'dmarc', :'dkim_verified' => :'dkimVerified', :'dmarc_verified' => :'dmarcVerified', :'return_path_verified' => :'returnPathVerified', :'track_verified' => :'trackVerified', :'verified' => :'verified', :'domain_registered_date' => :'domainRegisteredDate', :'created' => :'created', :'dkim_failure_reason' => :'dkimFailureReason', :'dmarc_failure_reason' => :'dmarcFailureReason', :'track_failure_reason' => :'trackFailureReason', :'return_path_failure_reason' => :'returnPathFailureReason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 132 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 108 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'dns_provider' => :'String', :'dkim' => :'DnsRecord', :'return_path' => :'DnsRecord', :'track' => :'DnsRecord', :'dmarc' => :'DnsRecord', :'dkim_verified' => :'Boolean', :'dmarc_verified' => :'Boolean', :'return_path_verified' => :'Boolean', :'track_verified' => :'Boolean', :'verified' => :'Boolean', :'domain_registered_date' => :'Date', :'created' => :'Integer', :'dkim_failure_reason' => :'String', :'dmarc_failure_reason' => :'String', :'track_failure_reason' => :'String', :'return_path_failure_reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && dns_provider == o.dns_provider && dkim == o.dkim && return_path == o.return_path && track == o.track && dmarc == o.dmarc && dkim_verified == o.dkim_verified && dmarc_verified == o.dmarc_verified && return_path_verified == o.return_path_verified && track_verified == o.track_verified && verified == o.verified && domain_registered_date == o.domain_registered_date && created == o.created && dkim_failure_reason == o.dkim_failure_reason && dmarc_failure_reason == o.dmarc_failure_reason && track_failure_reason == o.track_failure_reason && return_path_failure_reason == o.return_path_failure_reason end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 376 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 274 def hash [id, name, dns_provider, dkim, return_path, track, dmarc, dkim_verified, dmarc_verified, return_path_verified, track_verified, verified, domain_registered_date, created, dkim_failure_reason, dmarc_failure_reason, track_failure_reason, return_path_failure_reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
228 229 230 231 232 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 228 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
352 353 354 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 352 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 358 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
346 347 348 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 346 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
236 237 238 239 |
# File 'lib/sendpost_ruby_sdk/models/domain.rb', line 236 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |